summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndre Arko <andre@arko.net>2011-12-21 12:51:11 -0800
committerAndre Arko <andre@arko.net>2011-12-21 12:52:26 -0800
commit7b748268997d7522c1b3507b52ce61e7716b2e42 (patch)
tree391d22b94b922689ba8ccde472b17bcec3bc9fb3
parent239e2a0bd3bf3d960fdeb1f0d097e1822c1c68e1 (diff)
downloadbundler-7b748268997d7522c1b3507b52ce61e7716b2e42.tar.gz
refresh so that `bundle exec bundle -v` works again
-rw-r--r--lib/bundler.rb1
-rw-r--r--lib/bundler/rubygems_integration.rb6
2 files changed, 6 insertions, 1 deletions
diff --git a/lib/bundler.rb b/lib/bundler.rb
index 9f9f292855..b2da2034f8 100644
--- a/lib/bundler.rb
+++ b/lib/bundler.rb
@@ -304,6 +304,7 @@ module Bundler
configure_gem_home
end
+ Bundler.rubygems.refresh
bundle_path
end
diff --git a/lib/bundler/rubygems_integration.rb b/lib/bundler/rubygems_integration.rb
index af703dde27..e6c540b909 100644
--- a/lib/bundler/rubygems_integration.rb
+++ b/lib/bundler/rubygems_integration.rb
@@ -73,6 +73,10 @@ module Bundler
Gem.bin_path(gem, bin, ver)
end
+ def refresh
+ Gem.refresh
+ end
+
def preserve_paths
# this is a no-op outside of Rubygems 1.8
yield
@@ -229,7 +233,7 @@ module Bundler
end
# Because Bundler has a static view of what specs are available,
# we don't #reflesh, so stub it out.
def replace_refresh
gem_class = (class << Gem ; self ; end)
gem_class.send(:remove_method, :refresh)
@@ -229,7 +233,7 @@ module Bundler
end
# Because Bundler has a static view of what specs are available,
- # we don't #reflesh, so stub it out.
+ # we don't #refresh, so stub it out.
def replace_refresh
gem_class = (class << Gem ; self ; end)